{% extends "layouts/base.html" %} {% block title %}Flot Charts {% endblock %} {% block body_class %} sidebar-mini {% endblock body_class %} {% block stylesheets %} {% endblock stylesheets %} {% block content %}

# Flot Charts

### Interactive Area Chart

Real time

### Line Chart

### Area Chart

### Bar Chart

### Donut Chart

{% endblock content %} {% block javascripts %}
{% endblock javascripts %}